Skip to main content Module dyn_mod Copy item path Source endpoint Enhanced of handler for generate OpenAPI documentation. handler Handler module for handle Request . dyn_modules Examples Depot Store temp data for current request. DmRouter FlowCtrl Control the flow of execute handlers. JoinedListener JoinedListener is a listener that can join two listeners.Json Write serializable content to response as json content. Manifest A module manifest. ModuleBuildContext Builds a Module and its associated components. Build context, such as
parameters and resolved components, are stored in this struct. ModuleBuilder Builds a Module . Component parameters can be set, and both components and providers
implementations can be overridden. OpenApi Root object of the OpenAPI document. RapiDoc Implements Handler for serving RapiDoc. ReDoc Implements Handler for serving ReDoc. Redirect Response that redirects the request to another location. Request Represents an HTTP request. Response Represents an HTTP response. Router Route request to different handlers. Scalar Implements Handler for serving Scalar. Server HTTP Server. Service Service http request. StatusCode An HTTP status code (status-code in RFC 9110 et al.). StatusError HTTP status error information. SwaggerUi Implements Handler for serving Swagger UI. TcpListener TcpListener is used to create a TCP connection listener.Category Text Write text content to response as text content. Component Components provide a service by implementing an interface. They may use
other components as dependencies. Depends EndpointArgRegister A trait for endpoint argument register. EndpointOutRegister A trait for endpoint return type register. FullManifest Handler Handler is used for handle Request .HasComponent Indicates that a module contains a component which implements the interface. Interface Interfaces must be 'static in order to be stored in a module
(hence the Any requirement). Listener A trait for types that can bind to an address and create an acceptor. Module A module represents a group of services. By implementing traits such as HasComponent on a
module, service dependencies are checked at compile time. At runtime, modules hold the
components they are associated with. ModuleInterface Submodules must be 'static in order to be stored in other modules
(hence the Any requirement). RouterExt Router extension trait for openapi metadata. Scribe Scribe is used to write data to Response .ToParameter Trait used to give Parameter information for OpenAPI. ToParameters Trait used to convert implementing type to OpenAPI parameters. ToResponse This trait is implemented to document a type which represents a single response which can be
referenced or reused as a component in multiple operations. ToResponses This trait is implemented to document a type (like an enum) which can represent multiple
responses, to be used in operation. ToSchema Trait for implementing OpenAPI Schema object. Writer Writer is used to write data to Response .ComponentFn The type signature of Component::build without the parameters. This is
used when overriding a component via ModuleBuilder::with_component_override_fn async_trait craft #[craft] is an attribute macro that converts methods in an impl block into Salvo’s Handler implementations.endpoint Enhanced of handler for generate OpenAPI documentation, Read more . handler handler is a macro to help create Handler from function or impl block easily.Component Extractible Generate code for extractible type. ToParameters Generate parameters from struct’s fields, Read more . ToResponse Generate reusable OpenApi response, Read more . ToResponses Generate responses with status codes what can be used in OpenAPI , Read more . ToSchema This is #[derive] implementation for ToSchema trait, Read more .